<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright (C) 2002 Hewlett-Packard Development Group, L.P. -->
<!DOCTYPE xsl:stylesheet [
<!ENTITY % common_en SYSTEM "../dtd.en/common.dtd">
%common_en;
]>
<!-- end of localization preface -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:include href="vcrm_displayname.xsl"/>
   <xsl:output method="html" indent="yes"/>
   <!-- this template displays the name and descriptive info -->
   <xsl:template name="item_info">
      <xsl:param name="lang"/>
      <xsl:if test="name">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_name;</b>
            </td>
            <td class="cpqsrcatalog">
               <xsl:call-template name="display_name">
                  <xsl:with-param name="lang" select="$lang"/>
                  <xsl:with-param name="add_langs">false</xsl:with-param>
               </xsl:call-template>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="version">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_version;</b>
            </td>
            <td class="cpqsrcatalog">
               <xsl:value-of select="version/@value"/>
               <xsl:value-of select="version/@revision"/>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="languages">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_languages;</b>
            </td>
            <td class="cpqsrcatalog">
               <xsl:choose>
                  <xsl:when test="languages/languages_xlate[@lang=$lang]">
                     <xsl:value-of select="languages/languages_xlate[@lang=$lang]"/>
                  </xsl:when>
                  <xsl:when test="languages/languages_xlate[@lang='en']">
                     <xsl:value-of select="languages/languages_xlate[@lang='en']"/>
                  </xsl:when>
                  <xsl:otherwise/>
               </xsl:choose>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="release_date/@year">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_release_date;</b>
            </td>
            <td class="cpqsrcatalog">
               <script language="JavaScript">
                     <!-- do not use "//" comments - VCA's vcrproxy code breaks them -->
                     var y, m, d, h, n, s;
                     y = <xsl:value-of select="release_date/@year"/>;
                     m = <xsl:value-of select="release_date/@month"/>;
                     if (m > 0) m = m - 1; /* month in XML is not 0-relative */
                     d = <xsl:value-of select="release_date/@day"/>;
                     document.write(&vcTS2LocalDate;(y, m, d));
                  </script>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="description">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_description;</b>
            </td>
            <td class="cpqsrcatalog">
               <xsl:choose>
                  <xsl:when test="description/description_xlate[@lang=$lang]">
                     <xsl:value-of select="description/description_xlate[@lang=$lang]" disable-output-escaping="yes"/>
                  </xsl:when>
                  <xsl:when test="description/description_xlate[@lang='en']">
                     <xsl:value-of select="description/description_xlate[@lang='en']" disable-output-escaping="yes"/>
                  </xsl:when>
                  <xsl:otherwise/>
               </xsl:choose>
            </td>
         </tr>
      </xsl:if>
   </xsl:template>

   <!-- this template displays the various "notes" sections -->
   <xsl:template name="xml_notes">
      <xsl:param name="lang"/>
      <xsl:if test="prerequisite_notes/*">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_prereq_notes;</b>
            </td>
            <td class="cpqsrcatalog">
               <ul>
                  <xsl:choose>
                     <xsl:when test="prerequisite_notes/prerequisite_notes_xlate[@lang=$lang]">
                        <xsl:for-each select="prerequisite_notes/prerequisite_notes_xlate[@lang=$lang]/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:when test="prerequisite_notes/prerequisite_notes_xlate[@lang='en']">
                        <xsl:for-each select="prerequisite_notes/prerequisite_notes_xlate[@lang='en']/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:otherwise/>
                  </xsl:choose>
               </ul>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="installation_notes/*">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_install_notes;</b>
            </td>
            <td class="cpqsrcatalog">
               <ul>
                  <xsl:choose>
                     <xsl:when test="installation_notes/installation_notes_xlate[@lang=$lang]">
                        <xsl:for-each select="installation_notes/installation_notes_xlate[@lang=$lang]/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:when test="installation_notes/installation_notes_xlate[@lang='en']">
                        <xsl:for-each select="installation_notes/installation_notes_xlate[@lang='en']/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:otherwise/>
                  </xsl:choose>
               </ul>
            </td>
         </tr>
      </xsl:if>
      <xsl:if test="availability_notes/*">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_avail_notes;</b>
            </td>
            <td class="cpqsrcatalog">
               <ul>
                  <xsl:choose>
                     <xsl:when test="availability_notes/availability_notes_xlate[@lang=$lang]">
                        <xsl:for-each select="availability_notes/availability_notes_xlate[@lang=$lang]/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:when test="availability_notes/availability_notes_xlate[@lang='en']">
                        <xsl:for-each select="availability_notes/availability_notes_xlate[@lang='en']/*">
                           <li>
                              <xsl:value-of select="." disable-output-escaping="yes"/>
                           </li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:otherwise/>
                  </xsl:choose>
               </ul>
            </td>
         </tr>
      </xsl:if>
      <!-- don't show documentation notes because they contain relative links 
      <xsl:if test="documentation_notes/*">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog"><b>&cat_doc_notes;</b></td>
            <td class="cpqsrcatalog">
               <ul>
                  <xsl:choose>
                     <xsl:when test="documentation_notes/documentation_notes_xlate[@lang=$lang]">
                        <xsl:for-each select="documentation_notes/documentation_notes_xlate[@lang=$lang]/*">
                           <li><xsl:value-of select="." disable-output-escaping="yes"/></li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:when test="documentation_notes/documentation_notes_xlate[@lang='en']">
                        <xsl:for-each select="documentation_notes/documentation_notes_xlate[@lang='en']/*">
                           <li><xsl:value-of select="." disable-output-escaping="yes"/></li>
                        </xsl:for-each>
                     </xsl:when>
                     <xsl:otherwise>
                     </xsl:otherwise>
                  </xsl:choose>
               </ul>
            </td>
         </tr>
      </xsl:if>
      -->
   </xsl:template>

   <!-- this template outputs the revision history -->
   <xsl:template match="revision_history">
      <xsl:param name="lang"/>
      <xsl:if test="*">
         <tr class="cpqsrcatalog">
            <td class="cpqsrcatalog">
               <b>&cat_rev_hist;</b>
            </td>
            <td class="cpqsrcatalog">
               <xsl:for-each select="revision">
                  <div class="cpqsrcatalog-rhistheading">
                     <xsl:choose>
                        <xsl:when test="version/@type_of_change = 0">
                           <img src="&img_info;" title="&cat_enhancements;"/>
                           &#032;&cat_version;&#032;
                             <xsl:value-of select="version/@value"/>
                           <xsl:value-of select="version/@revision"/>
                           &#032;<small>(&cat_enhancements;)</small>
                        </xsl:when>
                        <xsl:when test="version/@type_of_change = 1">
                           <img src="&img_minor;" title="&cat_bug_fixes;"/>
                           &#032;&cat_version;&#032;
                             <xsl:value-of select="version/@value"/>
                           <xsl:value-of select="version/@revision"/>
                           &#032;<small>(&cat_bug_fixes;)</small>
                        </xsl:when>
                        <xsl:when test="version/@type_of_change = 2">
                           <img src="&img_major;" title="&cat_major_bug_fixes;"/>
                           &#032;&cat_version;&#032;
                             <xsl:value-of select="version/@value"/>
                           <xsl:value-of select="version/@revision"/>
                           &#032;<small>(&cat_major_bug_fixes;)</small>
                        </xsl:when>
                     </xsl:choose>
                  </div>
                  <div style="margin-left: 15px; margin-bottom:0px">
                     <xsl:if test="revision_enhancements_xlate">
                        <b>&cat_enhancements;</b>
                        <div style="margin-left:5px; margin-top:-15px; margin-bottom:0px">
                           <ul>
                              <xsl:choose>
                                 <xsl:when test="revision_enhancements_xlate[@lang=$lang]">
                                    <xsl:for-each select="revision_enhancements_xlate[@lang=$lang]/*">
                                       <li>
                                          <xsl:value-of select="." disable-output-escaping="yes"/>
                                       </li>
                                    </xsl:for-each>
                                 </xsl:when>
                                 <xsl:when test="revision_enhancements_xlate[@lang='en']">
                                    <xsl:for-each select="revision_enhancements_xlate[@lang='en']/*">
                                       <li>
                                          <xsl:value-of select="." disable-output-escaping="yes"/>
                                       </li>
                                    </xsl:for-each>
                                 </xsl:when>
                              </xsl:choose>
                           </ul>
                        </div>
                     </xsl:if>
                     <xsl:if test="revision_fixes_xlate">
                        <b>&cat_fixes;</b>
                        <div style="margin-left:5px; margin-top:-15px; margin-bottom:0px">
                           <ul>
                              <xsl:choose>
                                 <xsl:when test="revision_fixes_xlate[@lang=$lang]">
                                    <xsl:for-each select="revision_fixes_xlate[@lang=$lang]/*">
                                       <li>
                                          <xsl:value-of select="." disable-output-escaping="yes"/>
                                       </li>
                                    </xsl:for-each>
                                 </xsl:when>
                                 <xsl:when test="revision_fixes_xlate[@lang='en']">
                                    <xsl:for-each select="revision_fixes_xlate[@lang='en']/*">
                                       <li>
                                          <xsl:value-of select="." disable-output-escaping="yes"/>
                                       </li>
                                    </xsl:for-each>
                                 </xsl:when>
                              </xsl:choose>
                           </ul>
                        </div>
                     </xsl:if>
                  </div>
               </xsl:for-each>
            </td>
         </tr>
      </xsl:if>
   </xsl:template>

</xsl:stylesheet>
