<?xml version="1.0"?>
<!-- Copyright 2003 Hewlett-Packard Development Group, L.P. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output encoding="UTF-8" indent="yes" method="xml" version="1.0"/>
	<xsl:include href="vcrm_cattrans.xsl"/>
	<xsl:template match="/">
		<manifest_v1>
			<xsl:apply-templates/>
		</manifest_v1>
	</xsl:template>
	<xsl:template match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates select="node()"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="operating_system">
		<xsl:if test="@key!=''">
			<xsl:element name="operating_system">
				<xsl:attribute name="key"><xsl:value-of select="@key"></xsl:value-of></xsl:attribute>
				<xsl:copy-of select="./operating_system_xlate"></xsl:copy-of>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
	<!-- this template makes sure the key is lowercased to match what the VCA sends -->
	<xsl:template match="sw_key">
		<sw_key>
			<xsl:variable name="key_name">
				<xsl:value-of select="@name"/>
			</xsl:variable>
			<xsl:attribute name="name"><xsl:value-of select="translate($key_name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:attribute>
			<xsl:attribute name="version"><xsl:value-of select="@version"/></xsl:attribute>
			<xsl:apply-templates select="./*"/>
		</sw_key>
	</xsl:template>
	<!-- this template makes sure the package filenames in a bundle are lowercased -->
	<xsl:template match="package">
		<package>
			<xsl:apply-templates select="@*"/>
			<xsl:value-of select="translate(.,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>
		</package>
	</xsl:template>
	<xsl:template match="supported_operating_system">
		<xsl:if test="@name">
			<!-- Only if Name is present, Consider SOS, else use OS & statis XML -->
			<xsl:element name="supported_operating_system">
				<xsl:attribute name="platform"><xsl:value-of select="translate(@platform,'ABCDEFGHIJKLMNOPQRSTUVWXYZ_- ','abcdefghijklmnopqrstuvwxyz...')"/></xsl:attribute>
				<xsl:choose>
					<xsl:when test="@major">
						<xsl:apply-templates select="@major"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="major"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="@minor">
						<xsl:apply-templates select="@minor"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="minor"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:apply-templates select="@name"/>
				<xsl:choose>
					<xsl:when test="@os">
						<xsl:apply-templates select="@os"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="os"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="@sr">
						<xsl:attribute name="sr"><xsl:value-of select="translate(@sr,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:attribute>
					</xsl:when>
					<xsl:when test="@servicerel">
						<xsl:attribute name="sr"><xsl:value-of select="translate(@servicerel,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="sr"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose><!-- Work arounds to match with os_info.xml for duplicate entries-->
					<xsl:when test="contains(@name,'Vista')">
						<xsl:attribute name="edition">vista</xsl:attribute>	
					</xsl:when>
					<xsl:when test="contains(@name,'Unified Data Storage Server 2003 x64')">
						<xsl:attribute name="edition">udss</xsl:attribute>
					</xsl:when>
					<xsl:when test="contains(@name,'Windows 2000 Datacenter')">
						<xsl:attribute name="edition">dc</xsl:attribute>
					</xsl:when>
					<xsl:when test="contains(@name,'Storage Server 2003')">
						<xsl:attribute name="edition">ss</xsl:attribute>
					</xsl:when>
					<xsl:when test="contains(@name,'Advanced Server Limited Edition (IA64)')">
						<xsl:attribute name="edition">asl</xsl:attribute>
					</xsl:when>
					<xsl:when test="contains(@name,'Windows Powered OS')">
						<xsl:attribute name="edition">pos</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="edition"><xsl:value-of select="translate(@edition,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:attribute>					
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<!-- this template removes nodes we are sure we *don't* want -->
	<xsl:template match="families|superceded_packages|platform_specific|supported_devices|required_diskspace|installation|versioncompare"/> 
</xsl:stylesheet>
