<?xml version="1.0"?>
<!-- Copyright (C) 2001-2002 Hewlett-Packard Development Company, L.P. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="urn:my-script-block">
	<xsl:param name="request"/>
	<xsl:output encoding="UTF-8" indent="yes" method="xml" version="1.0"/>
	<xsl:variable name="input" select="msxsl:node-set($request)/method/input"/>
	<xsl:variable name="catalog" select="/cpqsrcatalog"/>
	<msxsl:script language="jscript" implements-prefix="user"><![CDATA[
        function compare(ver1, ver2) {
            var result = 0;
            var a1 = ver1.split('.');
            var a2 = ver2.split('.');
            for (var i = 0; i != a1.length; i++) {
                if (i >= a2.length) {
                    result = 1; break;
                }
                var s1 = a1[i];
                var s2 = a2[i];
                var n1 = parseInt(s1, 16);
                var n2 = parseInt(s2, 16);
                if (n1 == NaN || n2 == NaN)
                {
                    if (n1 == NaN && n2 == NaN)
                    {
                        if (s1 < s2) 
                        {
                            result = -1; break;
                        }
                        if (s1 > s2) 
                        {
                            result = 1; break;
                        }
                  }
                    else if (n1 == NaN) 
                    {
                        result = -1; break;
                    }
                    else {
                        result = 1; break;
                    }
                }
                else {
                    if (n1 < n2) {
                        result = -1; break;
                    }
                    if (n1 > n2) {
                        result = 1; break;
                    }
                }
            }
            if (result == 0 && a1.length < a2.length) {
                result = -1;
            }
            return result;
         }

        function sortVersions(nsAlgorithm, nsVersionNodeList)
        {
            var iIndex;
            // store the versions in an array
            var aVersions = new Array(nsVersionNodeList.length);
            for(iIndex = 0; iIndex < aVersions.length; iIndex++)
                aVersions[iIndex] = nsVersionNodeList.item(iIndex).getAttribute("value");

            if(nsAlgorithm.length == 0)
            {
                // use the default sort
                aVersions.sort(compare);
            }
            else
            {
                // build a script block with the supplied sort function
                var sScript;
                sScript = nsAlgorithm.item(0).text;
                sScript += " aVersions.sort(compare);";
                // execute the script
                eval(sScript);
            }

            // build the result document
            var oDoc = new ActiveXObject("MSXML2.DOMDocument");
            var oParent = oDoc.createElement("versions");
            for(iIndex = aVersions.length - 1; iIndex >= 0; iIndex--)
            {
                var oChild = oDoc.createElement("version");
                oChild.setAttribute("value", aVersions[iIndex]);
                oParent.appendChild(oChild);
            }

            // return the nodeset of version elements
            var oResultSet = oParent.selectNodes("version");
            return oResultSet;
        }
    ]]></msxsl:script>
	<xsl:template match="/">
		<xsl:element name="method">
			<xsl:attribute name="name">SRVersionCompare</xsl:attribute>
			<xsl:attribute name="type">response</xsl:attribute>
			<xsl:apply-templates select="cpqsrcatalog"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="cpqsrcatalog">
		<xsl:element name="output">
			<xsl:for-each select="$input/sw_key">
				<xsl:call-template name="sort">
					<xsl:with-param name="item" select="."/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template name="sort">
		<xsl:param name="item"/>
		<xsl:variable name="keydivision" select="$item/@division"/>
		<xsl:variable name="keyos" select="$item/@operating_system"/>
		<xsl:variable name="keysw" select="$item/@name"/>

		<xsl:variable name="keyplat" select="substring-after(substring-before($keyos,'MA'),'PL')"/>
		<xsl:variable name="keymaj" select="substring-after(substring-before($keyos,'MI'),'MA')"/>
		<xsl:variable name="keymin" select="substring-after(substring-before($keyos,'SR'),'MI')"/>
		<xsl:variable name="keysr" select="substring-after(substring-before($keyos,'ED'),'SR')"/>
		<xsl:variable name="keyedi" select="substring-after($keyos,'ED')"/>
		
		<xsl:variable name="temp_FilteredPackages">
			<xsl:choose>
				<xsl:when test="$keyplat = ''">
          <xsl:copy-of select="$catalog/cpq_package[divisions/division/@key=$keydivision and .//supported_operating_system[@os=$keyos]]"/>
				</xsl:when>
				<xsl:otherwise>
          <xsl:copy-of select="$catalog/cpq_package[divisions/division/@key=$keydivision and .//supported_operating_system[@platform=$keyplat and @major=$keymaj and @minor=$keymin and @sr=$keysr and @edition=$keyedi]]"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="nsFilteredPackages" select="msxsl:node-set($temp_FilteredPackages)/cpq_package"/>
		<xsl:variable name="nodeSortedPackages">
			<xsl:for-each select="$nsFilteredPackages[sw_keys/sw_keys_and/sw_key/@name=$keysw]">
				<xsl:sort select="substring-before(version/@value,'.')" data-type="number" order="descending"/>
				<xsl:sort select="substring-before(substring-after(version/@value,'.'),'.')" data-type="number" order="descending"/>
				<xsl:sort select="substring-before(substring-after(substring-after(version/@value,'.'),'.'),'.')" data-type="number" order="descending"/>
				<xsl:sort select="substring-after(substring-after(substring-after(version/@value,'.'),'.'),'.')" data-type="number" order="descending"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="nNewestPackage" select="msxsl:node-set($nodeSortedPackages)[sw_keys/sw_keys_and/sw_key/@name=$keysw][1]"/>
		<xsl:variable name="vc_method">
			<xsl:choose>
				<xsl:when test="$nNewestPackage">
					<xsl:value-of select="$nNewestPackage/versioncompare/vcmethod"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="sw_key">
			<xsl:attribute name="name"><xsl:value-of select="$keysw"/></xsl:attribute>
			<xsl:attribute name="division"><xsl:value-of select="$keydivision"/></xsl:attribute>
			<xsl:attribute name="operating_system"><xsl:value-of select="$keyos"/></xsl:attribute>
			<xsl:if test="$item/@langs">
				<xsl:attribute name="langs"><xsl:value-of select="$item/@langs"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="$item/@category">
				<xsl:attribute name="category"><xsl:value-of select="$item/@category"/></xsl:attribute>
			</xsl:if>
			<xsl:copy-of select="user:sortVersions(string($vc_method), $item/version)"/>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
